Installation
=====================

Via pip
--------------------------------

.. code-block:: sh

    pip install bte-pytorch


Via source
--------------------------------

You can download the code directly and put it in your project directory.

.. code-block:: sh

    git clone https://github.com/li-positive-one/bte-pytorch.git
